@@ -1,8 +1,6 @@
 # --
 # Kernel/GenericInterface/Operation/Ticket/TicketCreate.pm - GenericInterface Ticket TicketCreate operation backend
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: TicketCreate.pm,v 1.30.2.2 2013/01/03 10:26:50 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,8 +24,7 @@ use Kernel::GenericInterface::Operation::Common;
 use Kernel::GenericInterface::Operation::Ticket::Common;
 use Kernel::System::VariableCheck qw(IsArrayRefWithData IsHashRefWithData IsStringWithData);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.30.2.2 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -102,7 +99,7 @@ perform TicketCreate Operation. This will return the created ticket number.
             Password  => 'some password',                                       # if UserLogin or CustomerUserLogin is sent then
                                                                                 #   Password is required
 
-            Ticket {
+            Ticket => {
                 Title      => 'some ticket title',
 
                 QueueID       => 123,                                           # QueueID or Queue is required
@@ -137,7 +134,7 @@ perform TicketCreate Operation. This will return the created ticket number.
                     Minute => 05,
                 },
             },
-            Article {
+            Article => {
                 ArticleTypeID                   => 123,                        # optional
                 ArticleType                     => 'some article type name',   # optional
                 SenderTypeID                    => 123,                        # optional
@@ -168,12 +165,12 @@ perform TicketCreate Operation. This will return the created ticket number.
                 # ...
             ],
             # or
-            # DynamicField {
+            # DynamicField => {
             #    Name   => 'some name',
             #    Value  => $Value,
             #},
 
-            Attachment [
+            Attachment => [
                 {
                     Content     => 'content'                                 # base64 encoded
                     ContentType => 'some content type'
@@ -182,7 +179,7 @@ perform TicketCreate Operation. This will return the created ticket number.
                 # ...
             ],
             #or
-            #Attachment {
+            #Attachment => {
             #    Content     => 'content'
             #    ContentType => 'some content type'
             #    Filename    => 'some fine name'
@@ -272,7 +269,7 @@ sub Run {
     my $Ticket = $Param{Data}->{Ticket};
 
     # remove leading and trailing spaces
-    for my $Attribute ( keys %{$Ticket} ) {
+    for my $Attribute ( sort keys %{$Ticket} ) {
         if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
             #remove leading spaces
@@ -283,7 +280,7 @@ sub Run {
         }
     }
     if ( IsHashRefWithData( $Ticket->{PendingTime} ) ) {
-        for my $Attribute ( keys %{ $Ticket->{PendingTime} } ) {
+        for my $Attribute ( sort keys %{ $Ticket->{PendingTime} } ) {
             if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
                 #remove leading spaces
@@ -323,7 +320,7 @@ sub Run {
     $Article->{UserType} = $UserType;
 
     # remove leading and trailing spaces
-    for my $Attribute ( keys %{$Article} ) {
+    for my $Attribute ( sort keys %{$Article} ) {
         if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
             #remove leading spaces
@@ -334,7 +331,7 @@ sub Run {
         }
     }
     if ( IsHashRefWithData( $Article->{OrigHeader} ) ) {
-        for my $Attribute ( keys %{ $Article->{OrigHeader} } ) {
+        for my $Attribute ( sort keys %{ $Article->{OrigHeader} } ) {
             if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
                 #remove leading spaces
@@ -354,7 +351,9 @@ sub Run {
         $Article->{ArticleType} = $Self->{Config}->{ArticleType} || '';
     }
     if ( !$Article->{SenderTypeID} && !$Article->{SenderType} ) {
-        $Article->{SenderType} = $Self->{Config}->{SenderType} || '';
+
+        # $Article->{SenderType} = $Self->{Config}->{SenderType} || '';
+        $Article->{SenderType} = $UserType eq 'Agent' ? 'agent' : 'customer';
     }
     if ( !$Article->{HistoryType} ) {
         $Article->{HistoryType} = $Self->{Config}->{HistoryType} || '';
@@ -403,7 +402,7 @@ sub Run {
             }
 
             # remove leading and trailing spaces
-            for my $Attribute ( keys %{$DynamicFieldItem} ) {
+            for my $Attribute ( sort keys %{$DynamicFieldItem} ) {
                 if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
                     #remove leading spaces
@@ -450,7 +449,7 @@ sub Run {
             }
 
             # remove leading and trailing spaces
-            for my $Attribute ( keys %{$AttachmentItem} ) {
+            for my $Attribute ( sort keys %{$AttachmentItem} ) {
                 if ( ref $Attribute ne 'HASH' && ref $Attribute ne 'ARRAY' ) {
 
                     #remove leading spaces
@@ -1424,9 +1423,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.30.2.2 $ $Date: 2013/01/03 10:26:50 $
-
-=cut
