@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminAutoResponse.pm - provides admin std response module
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminAutoResponse.pm,v 1.49 2012-02-27 22:53:37 ep Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,9 +17,6 @@ use Kernel::System::SystemAddress;
 use Kernel::System::Valid;
 use Kernel::System::HTMLUtils;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.49 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -101,8 +96,9 @@ sub Run {
 
             # update group
             if (
-                $Self->{AutoResponseObject}
-                ->AutoResponseUpdate( %GetParam, UserID => $Self->{UserID} )
+                $Self->{AutoResponseObject}->AutoResponseUpdate(
+                    %GetParam, UserID => $Self->{UserID}
+                )
                 )
             {
                 $Self->_Overview();
