@@ -1,8 +1,6 @@
 # --
 # Kernel/System/GenericInterface/Webservice.pm - GenericInterface webservice config backend
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Webservice.pm,v 1.30 2012-03-29 07:29:21 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,17 +12,16 @@ package Kernel::System::GenericInterface::Webservice;
 use strict;
 use warnings;
 
-use YAML;
+use Kernel::System::YAML;
 use Kernel::System::Valid;
 use Kernel::System::GenericInterface::DebugLog;
 use Kernel::System::GenericInterface::WebserviceHistory;
 use Kernel::System::GenericInterface::ObjectLockState;
 use Kernel::System::Cache;
 
-use Kernel::System::VariableCheck qw(IsHashRefWithData);
+use Kernel::System::VariableCheck qw(:all);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.30 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -106,6 +103,7 @@ sub new {
         = Kernel::System::GenericInterface::WebserviceHistory->new( %{$Self} );
     $Self->{ObjectLockStateObject}
         = Kernel::System::GenericInterface::ObjectLockState->new( %{$Self} );
+    $Self->{YAMLObject} = Kernel::System::YAML->new( %{$Self} );
 
     # get the cache TTL (in seconds)
     $Self->{CacheTTL}
@@ -140,8 +138,60 @@ sub WebserviceAdd {
         }
     }
 
+    # check config
+    if ( !IsHashRefWithData( $Param{Config} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config should be a non empty hash reference!",
+        );
+        return;
+    }
+
+    # check config internals
+    if ( !IsHashRefWithData( $Param{Config}->{Debugger} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Debugger should be a non empty hash reference!",
+        );
+        return;
+    }
+    if ( !IsStringWithData( $Param{Config}->{Debugger}->{DebugThreshold} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Debugger DebugThreshold should be a non empty string!",
+        );
+        return;
+    }
+    if ( !defined $Param{Config}->{Provider} && !defined $Param{Config}->{Requester} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Provider or Requester should be defined!",
+        );
+        return;
+    }
+    for my $CommunicationType (qw(Provider Requester)) {
+        if ( defined $Param{Config}->{$CommunicationType} ) {
+            if ( !IsHashRefWithData( $Param{Config}->{$CommunicationType} ) ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Webservice Config $CommunicationType should be a non empty hash"
+                        . " reference!",
+                );
+                return;
+            }
+            if ( !IsHashRefWithData( $Param{Config}->{$CommunicationType}->{Transport} ) ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Webservice Config $CommunicationType Transport should be a"
+                        . " non empty hash reference!",
+                );
+                return;
+            }
+        }
+    }
+
     # dump config as string
-    my $Config = YAML::Dump( $Param{Config} );
+    my $Config = $Self->{YAMLObject}->Dump( Data => $Param{Config} );
 
     # md5 of content
     my $MD5 = $Self->{MainObject}->MD5sum(
@@ -251,7 +301,8 @@ sub WebserviceGet {
 
     my %Data;
     while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
-        my $Config = YAML::Load( $Data[2] );
+
+        my $Config = $Self->{YAMLObject}->Load( Data => $Data[2] );
 
         %Data = (
             ID         => $Data[0],
@@ -301,8 +352,60 @@ sub WebserviceUpdate {
         }
     }
 
+    # check config
+    if ( !IsHashRefWithData( $Param{Config} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config should be a non empty hash reference!",
+        );
+        return;
+    }
+
+    # check config internals
+    if ( !IsHashRefWithData( $Param{Config}->{Debugger} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Debugger should be a non empty hash reference!",
+        );
+        return;
+    }
+    if ( !IsStringWithData( $Param{Config}->{Debugger}->{DebugThreshold} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Debugger DebugThreshold should be a non empty string!",
+        );
+        return;
+    }
+    if ( !defined $Param{Config}->{Provider} && !defined $Param{Config}->{Requester} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Webservice Config Provider or Requester should be defined!",
+        );
+        return;
+    }
+    for my $CommunicationType (qw(Provider Requester)) {
+        if ( defined $Param{Config}->{$CommunicationType} ) {
+            if ( !IsHashRefWithData( $Param{Config}->{$CommunicationType} ) ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Webservice Config $CommunicationType should be a non empty hash"
+                        . " reference!",
+                );
+                return;
+            }
+            if ( !IsHashRefWithData( $Param{Config}->{$CommunicationType}->{Transport} ) ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Webservice Config $CommunicationType Transport should be a"
+                        . " non empty hash reference!",
+                );
+                return;
+            }
+        }
+    }
+
     # dump config as string
-    my $Config = YAML::Dump( $Param{Config} );
+    my $Config = $Self->{YAMLObject}->Dump( Data => $Param{Config} );
 
     # md5 of content
     my $MD5 = $Self->{MainObject}->MD5sum(
@@ -326,8 +429,8 @@ sub WebserviceUpdate {
     }
 
     return 1 if $ValidIDCurrent eq $Param{ValidID}
-            && $Config eq $ConfigCurrent
-            && $NameCurrent eq $Param{Name};
+        && $Config eq $ConfigCurrent
+        && $NameCurrent eq $Param{Name};
 
     # sql
     return if !$Self->{DBObject}->Do(
@@ -458,17 +561,11 @@ sub WebserviceList {
         $Data{ $Row[0] } = $Row[1];
     }
 
-    my $Value = {};
-
-    if (%Data) {
-        $Value = \%Data;
-    }
-
     # set cache
     $Self->{CacheObject}->Set(
         Type  => 'Webservice',
         Key   => $CacheKey,
-        Value => $Value,
+        Value => \%Data,
         TTL   => $Self->{CacheTTL},
     );
 
@@ -488,9 +585,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.30 $ $Date: 2012-03-29 07:29:21 $
-
-=cut
