@@ -17,8 +17,7 @@ use Kernel::System::Valid;
 use Kernel::System::CacheInternal;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.60 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -135,7 +134,7 @@ sub ServiceList {
     # read cache
     my $CacheKey = 'ServiceList::' . $Param{Valid};
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return %{$Cache} if ref $Cache eq 'HASH';
 
     # ask database
     $Self->{DBObject}->Prepare(
@@ -398,7 +397,7 @@ sub ServiceGet {
     # check cached results
     my $CacheKey = 'Cache::ServiceGet::' . $Param{ServiceID};
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return %{$Cache} if ref $Cache eq 'HASH';
 
     # get service from db
     $Self->{DBObject}->Prepare(
@@ -940,10 +939,10 @@ sub CustomerUserServiceMemberList {
     # check cache
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
     if ( $Param{Result} eq 'HASH' ) {
-        return %{$Cache} if $Cache;
+        return %{$Cache} if ref $Cache eq 'HASH';
     }
     else {
-        return @{$Cache} if $Cache;
+        return @{$Cache} if ref $Cache eq 'ARRAY';
     }
 
     # db quote
@@ -1138,7 +1137,7 @@ sub ServiceParentsGet {
     # read cache
     my $CacheKey = 'ServiceParentsGet::' . $Param{ServiceID};
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
-    return %{$Cache} if $Cache;
+    return $Cache if ref $Cache;
 
     # get the list of services
     my $ServiceList = $Self->ServiceListGet(
@@ -1199,9 +1198,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.60 $ $Date: 2012-11-20 15:38:02 $
-
-=cut
